
local MakePlayerCharacter = require "prefabs/player_common"


local assets = {
    Asset("SCRIPT", "scripts/prefabs/player_common.lua"),
}
local prefabs = {}

-- Custom starting items
local start_inv = {
	"flint",
	"flint",
	"flint",
}

-- When the character is revived from human
local function onbecamehuman(inst)
	-- Set speed when reviving from ghost (optional)
	inst.components.locomotor:SetExternalSpeedMultiplier(inst, "astarya_speed_mod", 1)
end

local function onbecameghost(inst)
	-- Remove speed modifier when becoming a ghost
   inst.components.locomotor:RemoveExternalSpeedMultiplier(inst, "astarya_speed_mod")
end

-- When loading or spawning the character
local function onload(inst)
    inst:ListenForEvent("ms_respawnedfromghost", onbecamehuman)
    inst:ListenForEvent("ms_becameghost", onbecameghost)

    if inst:HasTag("playerghost") then
        onbecameghost(inst)
    else
        onbecamehuman(inst)
    end
end


-- This initializes for both the server and client. Tags can be added here.
local common_postinit = function(inst) 
	-- Minimap icon
	inst.MiniMapEntity:SetIcon( "astarya.tex" )
end

-- This initializes for the server only. Components are added here.
local master_postinit = function(inst)
	-- choose which sounds this character will play
	inst.soundsname = "astarya"

	-- Uncomment if "wathgrithr"(Wigfrid) or "webber" voice is used
    --inst.talker_path_override = "dontstarve_DLC001/characters/"

	-- Health Regen
	inst.components.health:StartRegen(0.1, 1) -- X amount of health per, y amount of seconds. Default 0.1 per 1


	-- Flat Damage bonus
	inst:ListenForEvent("onattackother", function(inst, data)
	data.target.components.health:DoDelta(-25) -- This does NOT get multiplied by damage mult.
	end)

	-- Stats	
	inst.components.health:SetMaxHealth(200)
	inst.components.hunger:SetMax(200)
	inst.components.sanity:SetMax(100)
	
	-- Sanity effects
	inst.components.sanity.night_drain_mult = 1.0
	inst.components.sanity.neg_aura_mult = 0.0

	-- Movement speed
	inst.components.locomotor.runspeed = TUNING.WILSON_RUN_SPEED * 1.25

	-- Innate insulation (fur)
	inst.components.temperature.inherentinsulation = 25

	-- Defense multiplier
	inst.components.health:SetAbsorptionAmount(0.5)

	-- Damage multiplier
    	inst.components.combat.damagemultiplier = 2.0
	
	-- Hunger rate
	inst.components.hunger.hungerrate = 2.7 * TUNING.WILSON_HUNGER_RATE

	-- Spoilage Hate (equal to Wickerbottom)
	inst.components.eater.stale_hunger = TUNING.WICKERBOTTOM_STALE_FOOD_HUNGER
	inst.components.eater.stale_health = TUNING.WICKERBOTTOM_STALE_FOOD_HEALTH
	inst.components.eater.spoiled_hunger = TUNING.WICKERBOTTOM_SPOILED_FOOD_HUNGER
	inst.components.eater.spoiled_health = TUNING.WICKERBOTTOM_SPOILED_FOOD_HEALTH
	
	inst.OnLoad = onload
    inst.OnNewSpawn = onload
	
end

return MakePlayerCharacter("astarya", prefabs, assets, common_postinit, master_postinit, start_inv)
